```
Usage: vcd gateway services [OPTIONS] COMMAND [ARGS]...

  Configure services of gateway.

Options:
  -h, --help  Show this message and exit.

Commands:
  ca-certificate       Manage CA certificates of gateway
  crl-certificate      Manage CRL certificates of gateway
  dhcp-pool            manage DHCP pool of the gateway
  firewall             manage firewall rules of gateway
  ipsec-vpn            Manage ipsec vpn of gateway
  nat                  manage snat/dnat rules of gateway
  service-certificate  Manage certificates of gateway
  static-route         manage static routes of gateway

```
